// copyright(C) KatsuhikoTerawaki CA co.,ltd

#include <stdlib.h>
#include <ctype.h>
#include <string.h>
#include "mydefine.h"
#include "binary.h"
#include "etcstr.h"


static const char HexChar[] = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ" ;


/*-------------------------------------------------*/
/* Get a value of the string  http://elm-chan.org/ */
/*-------------------------------------------------*/
/*	"123 -5   0x3ff 0b1111 0377  w "
	    ^                           1st call returns 123 and next ptr
	       ^                        2nd call returns -5 and next ptr
                   ^                3rd call returns 1023 and next ptr
                          ^         4th call returns 15 and next ptr
                               ^    5th call returns 255 and next ptr
                                  ^ 6th call fails and returns 0
*/

int xatoi (			/* 0:Failed, 1:Successful */
	char **str,		/* Pointer to pointer to the string */
	long *res		/* Pointer to the valiable to store the value */
)
{
	unsigned long val;
	unsigned char c, r, s = 0;


	*res = 0;

	while ((c = **str) == ' ') (*str)++;	/* Skip leading spaces */

	if (c == '-') {		/* negative? */
		s = 1;
		c = *(++(*str));
	}

	if (c == '0') {
		c = *(++(*str));
		switch (c) {
		case 'x':		/* hexdecimal */
			r = 16; c = *(++(*str));
			break;
		case 'b':		/* binary */
			r = 2; c = *(++(*str));
			break;
		default:
			if (c <= ' ') return 1;	/* single zero */
			if (c < '0' || c > '9') return 0;	/* invalid char */
			r = 8;		/* octal */
		}
	} else {
		if (c < '0' || c > '9') return 0;	/* EOL or invalid char */
		r = 10;			/* decimal */
	}

	val = 0;
	while (c > ' ') {
		if (c >= 'a') c -= 0x20;
		c -= '0';
		if (c >= 17) {
			c -= 7;
			if (c <= 9) return 0;	/* invalid char */
		}
		if (c >= r) return 0;		/* invalid char for current radix */
		val = val * r + c;
		c = *(++(*str));
	}
	if (s) val = 0 - val;			/* apply sign if needed */

	*res = val;
	return 1;
}


/******************************************************************************
機能要約 スペースコード等を読み捨てる
機能
引き数
戻り値
注意
******************************************************************************/
char* ReadOutWhiteSpace( char* Buffer )
{
    for(; *Buffer != 0 ; Buffer ++ ) {
        if( *Buffer != ' ' ) {
            if( *Buffer != '\t' ) {
                return( Buffer ) ;
            }
        }
    }
    return( Buffer ) ;
}




unsigned long power10( unsigned long Power )
{
    static const unsigned long Ans[] = { 1,  // 0 -> 4294967295
                                         10,
                                         100,
                                         1000,
                                         10000,
                                         100000,
                                         1000000,
                                         10000000,
                                         100000000,
                                         1000000000,
    } ;
    return( Ans[Power ] ) ;
}
/******************************************************************************
機能要約  int を5桁の10進文字列にする
機能
引数
  a 文字列にしたいデータ
戻り値
  文字列へのポインタ
注意 マルチスレッド対応では無い
******************************************************************************/
char* ItoA5( unsigned int a )
{
	static char Buffer[ 6 ] ;
	static const unsigned int Div[] = { 10000U, 1000U, 100U, 10U, 1U } ;
	int i ;

	for( i = 0 ; i < 5 ; i ++ ) {
		Buffer[ i ] = ( a / Div[ i ] ) + '0' ;
		a %= Div[ i ] ;
	}
	Buffer[ i ] = 0 ;
	return( Buffer ) ;
}
char* ZeroToSpace( char* Buffer )
{
	char* a ;
	a = Buffer ;
	for(; *Buffer != 0 ; Buffer ++ ) {
		if( *Buffer != '0' ) {
			break ;
		}
		if( Buffer[ 1 ] != 0 ) {  //最後の桁でないばあい
			*Buffer = ' ' ;
		}
	}
	return( a ) ;
}
unsigned long DigigValue(char c)
{
	c = tolower( (int)c ) ;
	if( isdigit( ( int )c ) )
		return( c - '0' ) ;
	if( islower( ( int ) c ) )
		return( c - 'a' + 10 ) ;
	return( 100 ) ;
}
long AtoL( char* s )
{
	long  v, radix;
	char  c, *p;

	p = s;

	for(;;) {
		if( isdigit( ( int )*p ) ) {
			break ;
		}
		if( *p == 0 ) {
			return( 0 ) ;
		}
		p ++ ;
	}

	c = *p;
	if (c != '0')
		radix = 10;   /* decimal */
	else if (*++p == 'x' || *p == 'X')
		p++, radix = 16;  /* hexadecimal */
	else
		radix = 8;    /* octal */

	v = 0;

	while ( ( long )(c = DigigValue(*p)) < radix) {
		v = v * radix + c;
		p++;
	}
	/* skip suffixes */
	while ((c = tolower((int)*p)) == 'u' || c == 'l')
		p++;
	return (v);
}
long A10toL( char* Buf )
{
	// 1〜9 までの数字が出てくるまで読み飛ばし.
	for( ; *Buf != 0 ; Buf ++ ) {
		if( ( '1' <= *Buf ) && ( *Buf <= '9' ) ) {
			return( AtoL( Buf ) ) ;
		}
	}
	return( 0 ) ;
}
unsigned long HexStrToLong( char* str, int keta )
{
    unsigned long ans = 0 ;
    while( 1 ) {
        unsigned long tmp ;
        tmp = DigigValue( *str ) & 0xff ;
        str ++ ;
        ans |= tmp ;

        keta -- ;
        if( keta == 0 ) {
            break ;
        }

        ans <<= 4 ;
    }
    return ans ;
}
/******************************************************************************
機能要約 浮動小数点数を文字列にする(色々な制限があるが、スタック消費が少ない)。
機能 全部の桁数は、long の10進数で表される桁数より大きくすることはできない。
引数
戻り値
注意
******************************************************************************/
char* FloatToStr( float Value, int DecimalLen, char PlusSign, char* String )
{
    unsigned long llValue ;
    char MinusFlag ;
    char* Buf ;

    if( Value < 0.0 ) {
        MinusFlag = 1 ;
        Value = ( 0.0 - Value ) ;
    }
    else {
        MinusFlag = 0 ;
    }
    llValue = ( long  )( Value * power10( DecimalLen ) );
    Buf = ItoA10( llValue ) ;
    InsertLetter( Buf, strlen( Buf ) - DecimalLen, '.' ) ;
    Buf = DeleteTopZero( Buf ) ;
    if( MinusFlag ) {
        InsertLetterToHead( Buf, '-' ) ;
    }
    else {
        if( PlusSign != 0 ) {
            InsertLetterToHead( Buf, PlusSign ) ;
        }
    }
    strcpy( String,  Buf ) ;
    return String ;
}
char* DeleteTopZero( char* Buf )
{
    while( 1 ) {
        if( *Buf != '0' ) {
            return Buf ;
        }
        Buf ++ ;
    }
}
char* InsertLetter( char* Buf, int InsertPoint, char InsertLetter )
{
    InsertLetterToHead( &( Buf[ InsertPoint ] ), InsertLetter ) ;
    return Buf ;
}
char* InsertLetterToHead( char* Buf, char InsertLetter )
{
    int Len, i ;
    Len = strlen( Buf ) ;
    for( i = Len  ; i >= 0 ; i -- ) {
        Buf[ i + 1 ] = Buf[ i ] ;
    }
    Buf[ 0 ] = InsertLetter ;
    return Buf ;
}
char Str2ToBcd( char* Buf )
{
	char Value ;
	Value = ( Buf[ 0 ] - '0' ) << 4 ;
	return( Value + ( Buf[ 1 ] - '0' ) ) ;
}
unsigned char Bcd2Data( unsigned char data )
{
    int a10, a1 ;
    a10 = ( data >> 4 )  ;
    a10 &= 0xf ;
    a1 = data ;
    a1 &= 0xf ;
    return a10 * 10 + a1 ;
}
unsigned char Data2Bcd( unsigned char data )
{
    int a10, a1 ;
    a10 = data / 10 ;
    a1 = data % 10 ;
    a10 <<= 4 ;
    return a10 | a1 ;
}
/******************************************************************************
機能要約	long を 10進文字列にする
機能
引数
	a	文字列にしたいデータ
戻り値
	文字列へのポインタ
注意
******************************************************************************/
char* ltoa( unsigned long a )
{
	static char* OrgBuffer ;
	if( a == 0 ) {
		return( "0" ) ;
	}
	OrgBuffer = ItoA10( a ) ;
	for(;*OrgBuffer != 0 ; OrgBuffer ++ ) {
		if( *OrgBuffer >= '1' ) {
			return( OrgBuffer ) ;
		}
	}
	return( "" ) ;
}
//注意 マルチスレッド対応では無い
char* ItoA10( unsigned long a )
{
    static char Str[ 12 ] ;
    return dectoaHead0( a, Str ) ;
}
/******************************************************************************
機能要約	long を符号付きの文字列にする
機能
引数
	a	文字列にしたいデータ
戻り値
	文字列へのポインタ
注意
    Str は、12桁以上
******************************************************************************/
char* dectoa_sign( long a, char* str )
{
    char buf[ 13 ] ;
    char* orgPtr ;
    char* ptr ;

    if( a == 0 ) {
        *str = '0' ;
        str[ 1 ] = 0 ;
        return str ;
    }
    orgPtr = str ;
    if( a & 0x80000000 ) {
        a = -a ;
        *str = '-' ;
        str ++ ;
    }
    ptr = dectoaHead0( ( unsigned long )a, buf ) ;
    while( *ptr == '0' ) {
        ptr ++ ;
    }
    strcpy( str, ptr ) ;
    return orgPtr ;
}
char* dectoaHead0( unsigned long a, char* Str )
{
	const int Keta = 2 ;
	static const unsigned long pow[] = {
		100000000u,
		1000000u,
		10000u,
		100u,
		1u, 0 } ;
	char* Buffer ;
	unsigned long* Pow ;

	Buffer = Str ;
	Pow = ( unsigned long* )pow ;

	while( *Pow != 0 ) {
		memcpy( Buffer, dectoa2( a / *Pow ) , Keta ) ;
		a %= ( *Pow ) ;
		Buffer += Keta ;
		Pow ++ ;
	}
	*Buffer = 0 ;
	return( Str ) ;
}
/******************************************************************************
機能要約
機能
引数
戻り値
注意
******************************************************************************/
unsigned char* ShiftJisToEuc( unsigned char* Euc, unsigned char* Jis, int Limit )
{
  int Length = 0 ;
  unsigned char* OrgEuc ;
  unsigned short HiCode,LoCode, Code ;
  OrgEuc = Euc ;
  for( ; *Jis != 0 ; ) {
    Code = *Jis & 0xff ;
    if( Code < 0x80 ) {         //alnum
      if( Length + 1 >= Limit ) {
        *Euc = 0 ;
        return( OrgEuc ) ;
      }
      *Euc = *Jis ;
      Euc ++ ;
      Jis ++ ;
      Length ++ ;
      continue ;
    }
    if( isKanaShiftJisCode( *Jis ) ) { //半角カナ
      if( Length + 2 >= Limit ) {
        *Euc = 0 ;
        return( OrgEuc ) ;
      }
      *Euc = EUC_HANKAKU_KANA ;
      Euc ++ ;
      *Euc = *Jis ;
      Euc ++ ;
      Length += 2 ;
      Jis ++ ;
      continue ;
    }
    //以下、漢字
    if( is1stShiftJisCode( *Jis ) == 0 ) {
      //エラー
      *Euc = 0 ;
      return( OrgEuc ) ;
    }
    if( Length + 2 >= Limit ) {
      *Euc = 0 ;
      return( OrgEuc ) ;
    }

    HiCode = ( *Jis ) & 0xff ;
    Jis ++ ;
    LoCode = ( *Jis ) & 0xff ;
    Jis ++ ;
    //fprintf( stderr,"Hi %02x Lo %02x\n", HiCode, LoCode ) ;
    if( LoCode == 0 ) {
      //エラー
      *Euc = 0 ;
      return( OrgEuc ) ;
    }

    if( HiCode < 0xa0 ) {
      HiCode -= 0x70 ;
    }
    else if( HiCode < 0xf0 ) {
      HiCode -= 0xb0 ;
    }
    if( LoCode >= 0x80 ) {
      LoCode -- ;
    }
    HiCode <<= 1 ;
    if( LoCode >= 0x9e ) {
      LoCode -= 0x5e ;
    }
    else {
      HiCode -- ;
    }
    LoCode -= 0x1f ;

    //fprintf( stderr,"Hi %02x Lo %02x\n", HiCode, LoCode ) ;

    *Euc = HiCode | 0x80 ;
    Euc ++ ;
    *Euc = LoCode | 0x80 ;
    Euc ++ ;
    Length += 2 ;
  }
  *Euc = 0 ;
  return( OrgEuc ) ;
}
/******************************************************************************
機能要約
機能
引数
戻り値
注意
******************************************************************************/
BOOL is1stShiftJisCode( unsigned int c )
{
  c &= 0xff ;
  if( ( 0x81 <= c ) && ( c <= 0x9f ) ) {
    return( TRUE ) ;
  }
  if( ( 0xe0 <= c ) && ( c <= 0xfc ) ) {
    return( TRUE ) ;
  }
  return( FALSE ) ;
}
/******************************************************************************
機能要約
機能
引数
戻り値
注意
******************************************************************************/
BOOL is2ndShiftJisCode( unsigned int c )
{
  c &= 0xff ;
  if( ( 0x40 <= c ) && ( c <= 0x7e ) ) {
    return( TRUE ) ;
  }
  if( ( 0x80 <= c ) && ( c <= 0xfc ) ) {
    return( TRUE ) ;
  }
  return( FALSE ) ;
}
/******************************************************************************
機能要約
機能
引数
戻り値
注意
******************************************************************************/
BOOL isKanaShiftJisCode( unsigned int c )
{
  c &= 0xff ;
  if( ( 0xa1 <= c ) && ( c <= 0xdf ) ) {
    return( TRUE ) ;
  }
  return( FALSE ) ;
}

