// copyright(C) KatsuhikoTerawaki CA co.,ltd

#include <string.h>

#include "mydefine.h"
#include "fifo.h"

//---------------------------
// RTOS Includes
//---------------------------
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"
#include "semphr.h"

// FIFO の総数が正常な場合には、0 を返す。あふれた場合には、0 以外を返す
static inline BOOL incrimentHowMany( FIFO_STRUC* fifo )
{
    ( fifo->howMany ) ++ ;
    if( fifo->howMany > fifo->maxSize ) {
        fifo->howMany = fifo->maxSize ;
        return 1 ;
    }
    return 0 ;
}
static inline short decrimentHowMany( FIFO_STRUC* fifo )
{
    ( fifo->howMany ) -- ;
    if( fifo->howMany < 0 ) {
        fifo->howMany = 0 ;
    }
    return fifo->howMany ;
}
static inline short incrimentPoint( FIFO_STRUC* fifo, short num )
{
    num ++ ;
    if( num >= fifo->maxSize ) {
        num = 0 ;
    }
    return num ;
}
// FIFO の初期化(char)
FIFO_STRUC* initFifo( FIFO_STRUC* fifo, void* buf, int max )
{
    fifo->entryPoint = 0 ;
    fifo->retrievePoint = 0 ;
    fifo->maxSize = max ;
    fifo->howMany = 0 ;
    fifo->buffer = buf ;
    fifo->elementSize = 1 ;
    return fifo ;
}

// FIFO に追加(char)
char entryFifoWithoutCheck( FIFO_STRUC* fifo, char data )
{
    ( (char* )( fifo->buffer ) )[ fifo->entryPoint]  = data ;
    if( incrimentHowMany( fifo )  ) {
        fifo->retrievePoint = fifo->entryPoint ;//FIFO があふれた場合には、無条件に古いデータ削除して更新
        fifo->entryPoint = incrimentPoint( fifo, fifo->entryPoint ) ;
    }
    else {
        fifo->entryPoint = incrimentPoint( fifo, fifo->entryPoint ) ;
    }
    return data ;
}
// FIFO に追加(char)
char entryFifo( FIFO_STRUC* fifo, char data )
{
    LOOP() {
        if( isFullFifo( fifo ) == FALSE ) {
            break ;
        }
        Sleep( 1 ) ;
    }
    return entryFifoWithoutCheck( fifo, data ) ;
}
// FIFO から回収(char)
char retrieveFifo( FIFO_STRUC* fifo )
{
    LOOP() {
        if( fifo->howMany != 0 ) {
            break ;
        }
        Sleep( 1 ) ;
    }
    char data = ( (char* )( fifo->buffer ) )[ fifo->retrievePoint ] ;
    decrimentHowMany( fifo ) ;
    fifo->retrievePoint = incrimentPoint( fifo, fifo->retrievePoint ) ;
    return data ;
}

int howManyFifo( FIFO_STRUC* fifo )
{
    return fifo->howMany ;
}

BOOL isFullFifo(  FIFO_STRUC* fifo )
{
    if( fifo->howMany >= fifo->maxSize ) {
        return TRUE ;
    }
    return FALSE ;
}

// FIFO の初期化。要素のサイズが 1 以外
FIFO_STRUC* initFifoElmnt( FIFO_STRUC* fifo, void* buf, int max, int elementSize )
{
    initFifo( fifo, buf, max ) ;
    fifo->elementSize = 1 ;
    return fifo ;
}

// FIFO に追加。要素のサイズが 1 以外
void* entryFifoElmntWithoutCheck( FIFO_STRUC* fifo, void* data )
{
    char* target = (char* )( fifo->buffer ) ;
    target += ( fifo->entryPoint * fifo->elementSize ) ;
    memcpy( target, data, fifo->elementSize ) ;

    if( incrimentHowMany( fifo )  ) {
        fifo->retrievePoint = fifo->entryPoint ; //FIFO があふれた場合には、無条件に古いデータ削除して更新
        fifo->entryPoint = incrimentPoint( fifo, fifo->entryPoint ) ;
    }
    else {
        fifo->entryPoint = incrimentPoint( fifo, fifo->entryPoint ) ;
    }
    return data ;
}
// FIFO に追加。要素のサイズが 1 以外
void* entryFifoElmnt( FIFO_STRUC* fifo, void* data )
{
    LOOP() {
        if( isFullFifo( fifo ) == FALSE ) {
            break ;
        }
        Sleep( 1 ) ;
    }
    return entryFifoElmntWithoutCheck( fifo, data ) ;
}


// FIFO から回収。要素のサイズが 1 以外
void* retrieveFifoElmnt( FIFO_STRUC* fifo, void* data )
{
    char* target = (char* )( fifo->buffer ) ;

    LOOP() {
        if( fifo->howMany != 0 ) {
            break ;
        }
        Sleep( 1 ) ;
    }

    target += ( fifo->entryPoint * fifo->elementSize ) ;
    memcpy( data, target, fifo->elementSize ) ;

    decrimentHowMany( fifo ) ;
    fifo->retrievePoint = incrimentPoint( fifo, fifo->retrievePoint ) ;
    return data ;
}

