/*------------------------------------------------------------------------/
/  Universal string handler for user console interface
/-------------------------------------------------------------------------/
/
/  Copyright (C) 2011, ChaN, all right reserved.
/
/ * This software is a free software and there is NO WARRANTY.
/ * No restriction on use. You can use, modify and redistribute it for
/   personal, non-profit or commercial products UNDER YOUR RESPONSIBILITY.
/ * Redistributions of source code must retain the above copyright notice.
/ http://elm-chan.org/
/-------------------------------------------------------------------------*/

#include <string.h>
#include <stdarg.h>

#include "xprintf.h"
#include "binary.h"

static void invalidPort( char a ){}  // xputc の初期値
void (*xputc)( char) = invalidPort ;	/* Pointer to the output stream */
//void (*xputc)( char)  ;	/* Pointer to the output stream */

/*----------------------------------------------*/
/* Put CHAR function                            */
/*----------------------------------------------*/
void set_stdout( DBG_OUTCHR_FUNC func )
{
    xputc = func ;
}

/*----------------------------------------------*/
/* Put a null-terminated string                 */
/*----------------------------------------------*/
void xputs ( const char* str )
{
	while (*str) {
        xputc(*str++);
    }
}

void xputlf( void )
{
    xputc( '\n' ) ;
}

/*----------------------------------------------*/
/* Formatted string output                      */
/*----------------------------------------------*/
/*  xprintf("%d", 1234);			"1234"
    xprintf("%6d,%3d%%", -200, 5);	"  -200,  5%"
    xprintf("%-6u", 100);			"100   "
    xprintf("%ld", 12345678L);		"12345678"
    xprintf("%04x", 0xA3);			"00a3"
    xprintf("%08LX", 0x123ABC);		"00123ABC"
    xprintf("%016b", 0x550F);		"0101010100001111"
    xprintf("%s", "String");		"String"
    xprintf("%-4s", "abc");			"abc "
    xprintf("%4s", "abc");			" abc"
    xprintf("%c", 'a');				"a"
    xprintf("%f", 10.0);            <xprintf lacks floating point support>
*/

static
void xvprintf (
	const char*	fmt,	/* Pointer to the format string */
	va_list arp			/* Pointer to arguments */
)
{
	unsigned int r, i, j, w, f;
	unsigned long v;
	char s[16], c, d, *p;


	for (;;) {
		c = *fmt++;					/* Get a char */
		if (!c) break;				/* End of format? */
		if (c != '%') {				/* Pass through it if not a % sequense */
            xputc(c);
            continue;
		}
		f = 0;
		c = *fmt++;					/* Get first char of the sequense */
		if (c == '0') {				/* Flag: '0' padded */
			f = 1; c = *fmt++;
		} else {
			if (c == '-') {			/* Flag: left justified */
				f = 2; c = *fmt++;
			}
		}
		for (w = 0; c >= '0' && c <= '9'; c = *fmt++)	/* Minimum width */
			w = w * 10 + c - '0';
		if (c == 'l' || c == 'L') {	/* Prefix: Size is long int */
			f |= 4; c = *fmt++;
		}
		if (!c) break;				/* End of format? */
		d = c;
		if (d >= 'a') d -= 0x20;
		switch (d) {				/* Type is... */
		case 'S' :					/* String */
			p = va_arg(arp, char*);
			for (j = 0; p[j]; j++) ;
			while (!(f & 2) && j++ < w) xputc(' ');
			xputs(p);
			while (j++ < w) xputc(' ');
			continue;
		case 'C' :					/* Character */
			xputc((char)va_arg(arp, int)); continue;
		case 'B' :					/* Binary */
			r = 2; break;
		case 'O' :					/* Octal */
			r = 8; break;
		case 'D' :					/* Signed decimal */
		case 'U' :					/* Unsigned decimal */
			r = 10; break;
		case 'X' :					/* Hexdecimal */
			r = 16; break;
		default:					/* Unknown type (passthrough) */
			xputc(c); continue;
		}

		/* Get an argument and put it in numeral */
		v = (f & 4) ? va_arg(arp, long) : ((d == 'D') ? (long)va_arg(arp, int) : (long)va_arg(arp, unsigned int));
		if (d == 'D' && (v & 0x80000000)) {
			v = 0 - v;
			f |= 8;
		}
		i = 0;
		do {
			d = (char)(v % r); v /= r;
			if (d > 9) d += (c == 'x') ? 0x27 : 0x07;
			s[i++] = d + '0';
		} while (v && i < sizeof(s));
		if (f & 8) s[i++] = '-';
		j = i; d = (f & 1) ? '0' : ' ';
		while (!(f & 2) && j++ < w) xputc(d);
		do xputc(s[--i]); while(i);
		while (j++ < w) xputc(' ');
	}
}
void xfputc(void** func_or_pointer, char c)
{
    //extern void* RomVectors ;  extern void* _etext ;
    //if( ( RomVectors <= ( *func_or_pointer ) ) && ( ( *func_or_pointer ) <= _etext ) ) {
    if( ( (void*)0 <= *func_or_pointer ) && ( *func_or_pointer <= (void*)0x100000 )  ) { //もっと良い判定方法が無いか????!!!!
        DBG_OUTCHR_FUNC func ; //関数へのポインタの場合
        func = (DBG_OUTCHR_FUNC)(*func_or_pointer) ;
        func( c ) ;
        return ;
    }
    else {
        char* buf ;
        buf = (char* )( *func_or_pointer ) ; //バッファの場合
        *buf = (unsigned char)c ;
        buf ++ ;
        *func_or_pointer = buf ;
    }
}

void xfputs ( void* func_or_pointer, const char* str )
{
	while (*str)
		xfputc(&func_or_pointer,*str++);
}


void xprintf (			/* Put a formatted string to the default device */
	const char*	fmt,	/* Pointer to the format string */
	...					/* Optional arguments */
)
{
	va_list arp;
	va_start(arp, fmt);
	xvprintf(fmt, arp);
	va_end(arp);
}


static void xvfprintf ( //xvprintf() のまね
                void* func_or_pointer,
	const char*	fmt,	/* Pointer to the format string */
	va_list arp			/* Pointer to arguments */
)
{
	unsigned int r, i, j, w, f;
	unsigned long v;
	char s[16], c, d, *p;


	for (;;) {
		c = *fmt++;					/* Get a char */
		if (!c) break;				/* End of format? */
		if (c != '%') {				/* Pass through it if not a % sequense */
            xfputc(&func_or_pointer,c);
            continue ;
		}
		f = 0;
		c = *fmt++;					/* Get first char of the sequense */
		if (c == '0') {				/* Flag: '0' padded */
			f = 1; c = *fmt++;
		} else {
			if (c == '-') {			/* Flag: left justified */
				f = 2; c = *fmt++;
			}
		}
		for (w = 0; c >= '0' && c <= '9'; c = *fmt++)	/* Minimum width */
			w = w * 10 + c - '0';
		if (c == 'l' || c == 'L') {	/* Prefix: Size is long int */
			f |= 4; c = *fmt++;
		}
		if (!c) break;				/* End of format? */
		d = c;
		if (d >= 'a') d -= 0x20;
		switch (d) {				/* Type is... */
		case 'S' :					/* String */
			p = va_arg(arp, char*);
			for (j = 0; p[j]; j++) ;
			while (!(f & 2) && j++ < w) xfputc(&func_or_pointer, ' ');
			xfputs(&func_or_pointer, p);
			while (j++ < w) xfputc( &func_or_pointer, ' ');
			continue;
		case 'C' :					/* Character */
			xfputc(&func_or_pointer, (char)va_arg(arp, int)); continue;
		case 'B' :					/* Binary */
			r = 2; break;
		case 'O' :					/* Octal */
			r = 8; break;
		case 'D' :					/* Signed decimal */
		case 'U' :					/* Unsigned decimal */
			r = 10; break;
		case 'X' :					/* Hexdecimal */
			r = 16; break;
		default:					/* Unknown type (passthrough) */
			xfputc(&func_or_pointer, c); continue;
		}

		/* Get an argument and put it in numeral */
		v = (f & 4) ? va_arg(arp, long) : ((d == 'D') ? (long)va_arg(arp, int) : (long)va_arg(arp, unsigned int));
		if (d == 'D' && (v & 0x80000000)) {
			v = 0 - v;
			f |= 8;
		}
		i = 0;
		do {
			d = (char)(v % r); v /= r;
			if (d > 9) d += (c == 'x') ? 0x27 : 0x07;
			s[i++] = d + '0';
		} while (v && i < sizeof(s));
		if (f & 8) s[i++] = '-';
		j = i; d = (f & 1) ? '0' : ' ';
		while (!(f & 2) && j++ < w) xfputc(&func_or_pointer, d);
		do xfputc(&func_or_pointer,s[--i]); while(i);
		while (j++ < w) xfputc(&func_or_pointer,' ');
	}
}


void xsprintf (			/* Put a formatted string to the memory */
	char* buff,			/* Pointer to the output buffer */
	const char*	fmt,	/* Pointer to the format string */
	...					/* Optional arguments */
)
{
	va_list arp;
	va_start(arp, fmt);
	xvfprintf(buff,fmt, arp);
	va_end(arp);
}

// func() は、1文字出力関数 void func(char data ) の形式
void xfprintf (					/* Put a formatted string to the specified device */
	void *func,	/* Pointer to the output function */
	const char*	fmt,			/* Pointer to the format string */
	...							/* Optional arguments */
)
{
	va_list arp;
	va_start(arp, fmt);
	xvfprintf(func, fmt, arp);
	va_end(arp);
}


/******************************************************************************
機能要約  
機能
引き数
戻り値
注意
******************************************************************************/
void putsStrings( const char* const HowToUse[] ) 
{
	int i ;
	for( i = 0 ; HowToUse[ i ] != 0 ; i ++ ) {
		xputs( ( char* )HowToUse[ i ] ) ;
        xputc( '\n' ) ;
	}
}



static void dump32( unsigned long data )
{
    xputs( hextoa8( data >> 24 ) ) ;
    xputs( hextoa8( data >> 16 ) ) ;
    xputs( hextoa8( data >> 8 ) ) ;
    xputs( hextoa8( data ) ) ;
}
static void dump16( unsigned int data )
{
    xputs( hextoa8( data >> 8 ) ) ;
    xputs( hextoa8( data ) ) ;
}

/*----------------------------------------------*/
/* Dump a line of binary dump                   */
/*----------------------------------------------*/
void put_dump (
	unsigned long addr,		/* Heading address value */
	int len,				/* Number of items to be dumped */
	int width				/* Size of the items (DW_CHAR, DW_SHORT, DW_LONG) */
)
{
	int i;
	const unsigned char *bp;
	const unsigned short *sp;
	const unsigned long *lp;
    void* buff = (void*)addr ;

	dump32( addr);		/* address */
    xputc( ' ' ) ;

	switch (width) {
	case DW_CHAR:
		bp = buff;
		for (i = 0; i < len; i++) {		/* Hexdecimal dump */
			xputs( hextoa8( bp[i] ) );
            xputc( ' ' ) ;
        }
		for (i = 0; i < len; i++)		/* ASCII dump */
			xputc((bp[i] >= ' ' && bp[i] <= '~') ? bp[i] : '.');
		break;
	case DW_SHORT:
		sp = buff;
		do {								/* Hexdecimal dump */
			dump16( *sp++);
		} while (--len);
		break;
	case DW_LONG:
		lp = buff;
		do								/* Hexdecimal dump */
			dump32( *lp++);
		while (--len);
		break;
	}

	xputc('\n');
}

void DumpAddress16( unsigned long Start )
{
    put_dump( Start, 16, DW_CHAR ) ;
}

