/*******************************************************************************
* File Name: GEIGER_INTRPT.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <cydevice_trm.h>
#include <CyLib.h>
#include <GEIGER_INTRPT.h>

#if !defined(GEIGER_INTRPT__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START GEIGER_INTRPT_intc` */

/* `#END` */

extern cyisraddress CyRamVectors[CYINT_IRQ_BASE + CY_NUM_INTERRUPTS];

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: GEIGER_INTRPT_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GEIGER_INTRPT_Start(void)
{
    /* For all we know the interrupt is active. */
    GEIGER_INTRPT_Disable();

    /* Set the ISR to point to the GEIGER_INTRPT Interrupt. */
    GEIGER_INTRPT_SetVector(&GEIGER_INTRPT_Interrupt);

    /* Set the priority. */
    GEIGER_INTRPT_SetPriority((uint8)GEIGER_INTRPT_INTC_PRIOR_NUMBER);

    /* Enable it. */
    GEIGER_INTRPT_Enable();
}


/*******************************************************************************
* Function Name: GEIGER_INTRPT_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void GEIGER_INTRPT_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    GEIGER_INTRPT_Disable();

    /* Set the ISR to point to the GEIGER_INTRPT Interrupt. */
    GEIGER_INTRPT_SetVector(address);

    /* Set the priority. */
    GEIGER_INTRPT_SetPriority((uint8)GEIGER_INTRPT_INTC_PRIOR_NUMBER);

    /* Enable it. */
    GEIGER_INTRPT_Enable();
}


/*******************************************************************************
* Function Name: GEIGER_INTRPT_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void GEIGER_INTRPT_Stop(void)
{
    /* Disable this interrupt. */
    GEIGER_INTRPT_Disable();

    /* Set the ISR to point to the passive one. */
    GEIGER_INTRPT_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: GEIGER_INTRPT_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for GEIGER_INTRPT.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(GEIGER_INTRPT_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START GEIGER_INTRPT_Interrupt` */

    /* `#END` */
}


/*******************************************************************************
* Function Name: GEIGER_INTRPT_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling GEIGER_INTRPT_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use GEIGER_INTRPT_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void GEIGER_INTRPT_SetVector(cyisraddress address)
{
    CyRamVectors[CYINT_IRQ_BASE + GEIGER_INTRPT__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: GEIGER_INTRPT_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress GEIGER_INTRPT_GetVector(void)
{
    return CyRamVectors[CYINT_IRQ_BASE + GEIGER_INTRPT__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: GEIGER_INTRPT_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling GEIGER_INTRPT_Start
*   or GEIGER_INTRPT_StartEx will override any effect this method would 
*   have had. This method should only be called after GEIGER_INTRPT_Start or 
*   GEIGER_INTRPT_StartEx has been called. To set the initial
*   priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 3, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void GEIGER_INTRPT_SetPriority(uint8 priority)
{
	uint8 interruptState;
    uint32 priorityOffset = ((GEIGER_INTRPT__INTC_NUMBER % 4u) * 8u) + 6u;
    
	interruptState = CyEnterCriticalSection();
    *GEIGER_INTRPT_INTC_PRIOR = (*GEIGER_INTRPT_INTC_PRIOR & (uint32)(~GEIGER_INTRPT__INTC_PRIOR_MASK)) |
                                    ((uint32)priority << priorityOffset);
	CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: GEIGER_INTRPT_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 3, 0 being the highest.
*
*******************************************************************************/
uint8 GEIGER_INTRPT_GetPriority(void)
{
    uint32 priority;
	uint32 priorityOffset = ((GEIGER_INTRPT__INTC_NUMBER % 4u) * 8u) + 6u;

    priority = (*GEIGER_INTRPT_INTC_PRIOR & GEIGER_INTRPT__INTC_PRIOR_MASK) >> priorityOffset;

    return (uint8)priority;
}


/*******************************************************************************
* Function Name: GEIGER_INTRPT_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GEIGER_INTRPT_Enable(void)
{
    /* Enable the general interrupt. */
    *GEIGER_INTRPT_INTC_SET_EN = GEIGER_INTRPT__INTC_MASK;
}


/*******************************************************************************
* Function Name: GEIGER_INTRPT_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 GEIGER_INTRPT_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*GEIGER_INTRPT_INTC_SET_EN & (uint32)GEIGER_INTRPT__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: GEIGER_INTRPT_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GEIGER_INTRPT_Disable(void)
{
    /* Disable the general interrupt. */
    *GEIGER_INTRPT_INTC_CLR_EN = GEIGER_INTRPT__INTC_MASK;
}


/*******************************************************************************
* Function Name: GEIGER_INTRPT_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GEIGER_INTRPT_SetPending(void)
{
    *GEIGER_INTRPT_INTC_SET_PD = GEIGER_INTRPT__INTC_MASK;
}


/*******************************************************************************
* Function Name: GEIGER_INTRPT_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void GEIGER_INTRPT_ClearPending(void)
{
    *GEIGER_INTRPT_INTC_CLR_PD = GEIGER_INTRPT__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
