// copyright(C) KatsuhikoTerawaki CA co.,ltd

//---------------------------
// PSoC5 Includes
//---------------------------
#include <project.h>
#include <math.h>
//---------------------------
// RTOS Includes
//---------------------------
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"
#include "semphr.h"

//---------------------------
// API Includes
//---------------------------
#include "mydefine.h"
#include "fifo.h"
#include "xprintf.h"
#include "etcstr.h"
#include "uart2.h"
#include "i2c.h"
#include "GEIGER_INTRPT.h"
#include "motor.h"
//---------------------------
// capital program include
//---------------------------
#include "TaskAndroid.h"


static TASK TaskUart2Recv( void*p ) ;
static unsigned short GetCharWithTimeout( int timeOut ) ;
static char* GetCommandLine( int timeOut ) ;
static char* getValueStr( char *str ) ;

static BOOL dataOutStart ;

//書き込みは割り込みで行っているが、タスクでは読み込みだけ。かつ、読み込みプログラムは増分を求めているだけなので、
//適当な方法でも問題無い。
static volatile short GeigerCounter = 0 ;

#define TIME_CONSTANT_SEC 60
#define DATA_PER_SEC 2
#define NUM_OF_DATA ( TIME_CONSTANT_SEC * DATA_PER_SEC )

static char countHistry[ NUM_OF_DATA ] ;

//===========================
// Task : 
//===========================
TASK TaskAndroid( void*p )
{
    int i ;
    int sumOfCountData = 0 ;
    int dataPtr = 0 ;
    short lastCount = 0 ;
    GeigerCounter = 0 ;//割り込みで加算されるカウンタ
    for( i = 0 ; i < NUM_OF_DATA ; i ++ ) {
        countHistry[ i ] = 0 ;
    }
    
    CY_ISR_PROTO(GEIGER_INTRPT_Interrupt0);//割り込みルーチンの操作
    GEIGER_INTRPT_StartEx(GEIGER_INTRPT_Interrupt0);

    initUart2() ;//UART2 android に接続
    InitI2C() ;//I2Cの初期化

    dataOutStart = FALSE ;

    xTaskCreate(TaskUart2Recv,    (signed portCHAR *)"TaskUart2Recv"    , configMINIMAL_STACK_SIZE    , NULL, tskIDLE_PRIORITY , NULL);
    //size_t freeHeap = xPortGetFreeHeapSize() ;
    //xprintf( "TaskAndroid start %d\n",(int)freeHeap ) ;

    LOOP() {
        short readCount ; // GeigerCounter を一時保管
        short incrimentCount ; // 増分
        readCount = GeigerCounter ;//割り込みで加算されるカウンタを読み込む
        incrimentCount = readCount - lastCount ; //incrimentCountに 増分が求まった
        lastCount = readCount ;

        sumOfCountData -= countHistry[ dataPtr ] ;//過去データを減算
        countHistry[ dataPtr ] = incrimentCount ; //現データを追加
        sumOfCountData += incrimentCount ;      //現データを加算(カウント数更新)

        dataPtr ++ ;                            //過去データポインタを更新
        if( dataPtr >= NUM_OF_DATA ) {
            dataPtr = 0 ;
        }

        unsigned short a[ 2 ] ;
        a[0]=a[1]=1;
        //a[0] = GetAdcValue1() ;
        //a[1] = GetAdcValue2() ;
        if( dataOutStart ) {
            xfprintf( putcUart2, "%05d", sumOfCountData );
            xfprintf( putcUart2, "%05d%05d", a[0],a[1]);
            xfprintf( putcUart2, "%05d%05d%05d%05d\n", 0,0,0,0 );
        }
        Sleep( 500 ) ; //0.5秒待ち
    }
}
static TASK TaskUart2Recv( void*p )
{
    LOOP() {
        //dataOutStart = TRUE ;//debug
        char* str = GetCommandLine( 1000 ) ;
        if( str == NULL ) {
            continue ;
        }
        xprintf( "cmd=[%s]\n",str ) ;
        if( strcmp( str, "start" ) == 0 ) {
            xprintf( "cmd=start\n" ) ;
            dataOutStart = TRUE ;
        }
        else if( strcmp( str, "end" ) == 0 ) {
            xprintf( "cmd=end\n" ) ;
            dataOutStart = FALSE ;
        }
        else if( strcmp( str, "stop" ) == 0 ) {
            xprintf( "cmd=end\n" ) ;
            dataOutStart = FALSE ;
        }
        else {
            if( *str == 'r' ) {
                int motorChannel = str[ 1 ] - '0' ;
                BOOL sign = FALSE ;
                if( str[ 2 ] == '-' ) {
                    sign = TRUE ;
                }
                str = getValueStr( &( str[ 3 ] ) );
                long param ;
                xatoi( &str, &param ) ;
                if( sign ) {
                    param = -param ;
                }
                SetTamiyaGearBoxSpeed( motorChannel, param ) ;
            }
        }
    }
}

//xatoi に合わせるため
static char* getValueStr( char *str )
{
    while( 1 ) {
        if( ( '0' <= *str ) &&( *str <= '9' ) ) {
            return str ;
        }
        str ++ ;
    }
}

CY_ISR(GEIGER_INTRPT_Interrupt0)
{
    /*  Place your Interrupt code here. */
    /* `#START GEIGER_INTRPT_Interrupt` */
    //SW_ClearInterrupt();
    GEIGER_PLS_ClearInterrupt();
    GeigerCounter ++ ;
    /* `#END` */
}
short GetGeigerCount( void )
{
    return GeigerCounter ;
}
/******************************************************************************
機能要約 1行取得
機能
引き数
戻り値
注意
******************************************************************************/
static char* GetCommandLine( int timeOut )
{
    unsigned short data ;
    short i = 0 ;
    static char commandBuffer[ 20 ] ;
    //頭についたコントロールコード等を削除する.
    for(;;) {
        data = GetCharWithTimeout( -1 ) ;
        if( data > ' ' ) {
            break ;
        }
    }
    i = 0 ;
    commandBuffer[ i ] = ( char )data ;
    xputc( data ) ;

    for( i = 1 ; i < sizeof( commandBuffer ) ; ) {
        data = GetCharWithTimeout( timeOut ) ;
        if( data == NO_CHAR_DATA ) {
            return NULL ;
        }
        // CR とか LF の場合.
        if( data < ' ' ) {
            commandBuffer[ i ] = 0 ;
            xputc( '\n' ) ;
            return( commandBuffer ) ;
        }

        //通常のキャラクタの場合.
        commandBuffer[ i ] = data ;
        xputc( data ) ;
        i ++ ;
    }
    return( NULL ) ;
}
static unsigned short GetCharWithTimeout( int timeOut )
{
    const int tick = 10 ;
    if( timeOut < 0 ){
        LOOP() {
            unsigned short data = getcUart2() ;
            if( data != NO_CHAR_DATA ) {
                return data & 0xff ;
            }
            Sleep( tick ) ;
        }
    }
    LOOP() {
        unsigned short data = getcUart2() ;
        if( data != NO_CHAR_DATA ) {
            return data & 0xff ;
        }
        timeOut -= tick ;
        if( timeOut < 0 ) {
            return NO_CHAR_DATA ;
        }
        Sleep( tick ) ;
    }
}
