/*******************************************************************************
* File Name: ACCL_RST_PLUS.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "ACCL_RST_PLUS.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        ACCL_RST_PLUS_PC =   (ACCL_RST_PLUS_PC & \
                                (uint32)(~(uint32)(ACCL_RST_PLUS_DRIVE_MODE_IND_MASK << (ACCL_RST_PLUS_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (ACCL_RST_PLUS_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: ACCL_RST_PLUS_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void ACCL_RST_PLUS_Write(uint8 value) 
{
    uint8 drVal = (uint8)(ACCL_RST_PLUS_DR & (uint8)(~ACCL_RST_PLUS_MASK));
    drVal = (drVal | ((uint8)(value << ACCL_RST_PLUS_SHIFT) & ACCL_RST_PLUS_MASK));
    ACCL_RST_PLUS_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: ACCL_RST_PLUS_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  ACCL_RST_PLUS_DM_STRONG     Strong Drive 
*  ACCL_RST_PLUS_DM_OD_HI      Open Drain, Drives High 
*  ACCL_RST_PLUS_DM_OD_LO      Open Drain, Drives Low 
*  ACCL_RST_PLUS_DM_RES_UP     Resistive Pull Up 
*  ACCL_RST_PLUS_DM_RES_DWN    Resistive Pull Down 
*  ACCL_RST_PLUS_DM_RES_UPDWN  Resistive Pull Up/Down 
*  ACCL_RST_PLUS_DM_DIG_HIZ    High Impedance Digital 
*  ACCL_RST_PLUS_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void ACCL_RST_PLUS_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(ACCL_RST_PLUS__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: ACCL_RST_PLUS_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro ACCL_RST_PLUS_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 ACCL_RST_PLUS_Read(void) 
{
    return (uint8)((ACCL_RST_PLUS_PS & ACCL_RST_PLUS_MASK) >> ACCL_RST_PLUS_SHIFT);
}


/*******************************************************************************
* Function Name: ACCL_RST_PLUS_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 ACCL_RST_PLUS_ReadDataReg(void) 
{
    return (uint8)((ACCL_RST_PLUS_DR & ACCL_RST_PLUS_MASK) >> ACCL_RST_PLUS_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(ACCL_RST_PLUS_INTSTAT) 

    /*******************************************************************************
    * Function Name: ACCL_RST_PLUS_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 ACCL_RST_PLUS_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(ACCL_RST_PLUS_INTSTAT & ACCL_RST_PLUS_MASK);
		ACCL_RST_PLUS_INTSTAT = maskedStatus;
        return maskedStatus >> ACCL_RST_PLUS_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
