// copyright(C) KatsuhikoTerawaki CA co.,ltd

//---------------------------
// PSoC5 Includes
//---------------------------
#include <project.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

//---------------------------
// RTOS Includes
//---------------------------
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"
#include "semphr.h"

#include "mydefine.h"
#include "binary.h"
#include "etcstr.h"
#include "xprintf.h"
#include "monitor.h"

#include "uart1.h"
#include "uart2.h"

#include "i2c.h"
#include "Pin_1.h"

#include "TaskAndroid.h"
#include "motor.h"


#define WAIT_DELAY 100

static unsigned char GetChar( void );
static char* GetCommandLine( void );
static char* NextParameter( char* Buffer );
static void testAdress( void );
static void BlinkBlueLedForConfirmLive( void ) ;

#define MAX_COMMAND 64
#define VER_STR "1.00"

static MONITOR_GET_CHAR_FUNC GetCharFunc ;
static MONITOR_KBHIT_FUNC KeyHit ;

//char dust[ 200 ] ;

void Monitor( MONITOR_GET_CHAR_FUNC getchar, MONITOR_KBHIT_FUNC hit )
{
    static const char* const HowToUse[] = {
            "d memory dump"
          , "v version"
          , "2 uart2 monitor"
          , "3 geiger count"
          , "4 i2c motor0 -63 <-> -6  6 <-> 63  0 is free(tamiya gearbox 31〜63)"
          , "5 i2c motor1 -63 <-> -6  6 <-> 63  0 is free(tamiya gearbox 31〜63)"
          , "8 tamiya gearbox 0 0-100"
          , "9 tamiya gearbox 1 0-100"
          , 0
    } ;
    unsigned short key ;
    char* Buffer ;
    long Address, longParam ;
    int i ;

    GetCharFunc = getchar ;
    KeyHit = hit ;

    xputlf() ;
    xputs( "debug monitor " VER_STR " start \n" ) ;
    xputlf() ;

    putsStrings( HowToUse ) ;

    LOOP() {
        xputlf() ;
        xputs( "CA >" ) ;
        Buffer = GetCommandLine() ;
        if( Buffer == 0 ) {
            continue ;
        }
        xputlf() ;
        i = toupper( (int)*Buffer ) ;
        Buffer ++ ;
        switch( i ) {
        case '2' :
            xprintf( "Uart2 monitor\n" ) ;
            LOOP() {
                unsigned short data = getcUart2() ;
                if( data == NO_CHAR_DATA ) {
                    Sleep( 10 ) ;
                    if( KeyHit() ) {
                        break ;
                    }
                    continue ;
                }
                xprintf( "%c",data);
            }
            break ;
        case '3' :
            xprintf( "geiger=%05d\n", GetGeigerCount() );
            break ;
        case '4' :
            xatoi( &Buffer, &longParam ) ;
            SetMotorChannel( 0 ) ;
            xprintf( "SetVoltageAndDirection(%ld)\n", longParam ) ;
            SetVoltageAndDirection( longParam ) ;
            break ;
        case '5' :
            xatoi( &Buffer, &longParam ) ;
            SetMotorChannel( 1 ) ;
            xprintf( "SetVoltageAndDirection(%ld)\n", longParam ) ;
            SetVoltageAndDirection( longParam ) ;
            break ;
        case '8' :
            xatoi( &Buffer, &longParam ) ;
            xprintf( "SetTamiyaGearBoxSpeed(%ld)\n", longParam ) ;
            SetTamiyaGearBoxSpeed( 0, longParam ) ;
            break ;
        case '9' :
            xatoi( &Buffer, &longParam ) ;
            xprintf( "SetTamiyaGearBoxSpeed(%ld)\n", longParam ) ;
            SetTamiyaGearBoxSpeed( 1, longParam ) ;
            break ;
        case 'C' :
            Address = 0x20000000 ;
            LOOP() {
                if( KeyHit() == TRUE ) {
                    GetChar() ;
                    break ;
                }
                DumpAddress16( Address ) ;
                Address += 16 ;
                if( Address >= 0x20001000 ) {
                    break ;
                }
                Sleep(1);
            }
            xputlf() ;
            break ;
        case 'D' :
            Address = AtoL( Buffer ) ;
            LOOP() {
                if( KeyHit() == TRUE ) {
                    GetChar() ;
                    break ;
                }
                DumpAddress16( Address ) ;
                Address += 16 ;
                Sleep(1);
            }
            xputlf() ;
            break ;
        case 'V' :
            xputs( "\n" VER_STR "\n" ) ;
            break ;
        default :
            putsStrings( HowToUse ) ;
            break ;
        }
    }
}
/******************************************************************************
機能要約 1文字取得
機能
引き数
戻り値
注意
******************************************************************************/
static unsigned char GetChar( void )
{
    unsigned short a ;
    LOOP() {
        if( KeyHit() == FALSE ) {
            Sleep(2);
            BlinkBlueLedForConfirmLive() ;
            continue ;
        }
        a = GetCharFunc() ;
        return a & UCHAR_MAX ;
    }
}
//生存確認用LEDブリンク
//Psoc4はリソースが少なく、タスクを増やしたくないために、このようなことをやっている
static void BlinkBlueLedForConfirmLive( void )
{
    const portTickType mask = 0x3800ul ; /* 0000 0000 0000 0000 0011 1000 0000 0000 */
    portTickType nowTime = xTaskGetTickCount() ;
    nowTime &= mask ;
    if( nowTime == 0 ) {
        Pin_1_Write( 0 ) ;
    }
    else {
        Pin_1_Write( 1 ) ;
    }
}
/******************************************************************************
機能要約 1行取得
機能
引き数
戻り値
注意
******************************************************************************/
static char* GetCommandLine( void )
{
    char Data ;
    short i = 0 ;
    static char CommandBuffer[ MAX_COMMAND + 1 ] ;
    //頭についたコントロールコード等を削除する.
    for(;;) {
        Data = GetChar() ;
        if( Data > ' ' ) {
            xputc( Data ) ;
            break ;
        }
    }
    i = 0 ;
    CommandBuffer[ i ] = ( char )Data ;

    for( i = 1 ; i < MAX_COMMAND ; ) {
        Data = GetChar() ;
        //BS の場合.
        if( Data == BS ) {
            if( i > 0 ) {
                xputc( BS ) ;
                xputc( ' ' ) ;
                xputc( BS ) ;
                i -- ;
            }
            continue ;
        }
        // CR とか LF の場合.
        if( Data < ' ' ) {
            CommandBuffer[ i ] = 0 ;
            xputc( Data ) ;
            strlwr( CommandBuffer ) ;
            return( CommandBuffer ) ;
        }

        //通常のキャラクタの場合.
        CommandBuffer[ i ] = Data ;
        xputc( Data ) ;
        i ++ ;
    }
    return( 0 ) ;
}
/******************************************************************************
機能要約 次のパラメータを得る
機能
引き数
戻り値
注意
******************************************************************************/
static char* NextParameter( char* Buffer )
{
    Buffer ++ ;
    return( ReadOutWhiteSpace( Buffer ) ) ;
}
static void testAdress( void )
{
    extern long* RomVectors ;
    extern long* _etext ;
    extern long* __cy_interrupt_vector ;
    extern long* __cy_reset ;
    extern long* appl1_start ;
    extern long* Reset ;
    extern long* __cy_regions_end ;
    xprintf( "\n __cy_regions_end=%08lx appl1_start=%08lx Reset=%08lx\n",*__cy_regions_end, appl1_start,*Reset);
    Sleep(500);
    xprintf( "__cy_reset=%08lx __cy_interrupt_vector=%08lx RomVectors=%08lx _etext=%08lx\n",*__cy_reset,__cy_interrupt_vector,RomVectors, *_etext ) ;
    Sleep(500);
}

