// copyright(C) KatsuhikoTerawaki CA co.,ltd

//---------------------------
// PSoC5 Includes
//---------------------------
#include <project.h>
#include <math.h>
//---------------------------
// RTOS Includes
//---------------------------
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"
#include "semphr.h"

//---------------------------
// API Includes
//---------------------------
#include "mydefine.h"
#include "binary.h"
#include "fifo.h"
#include "xprintf.h"
#include "i2c.h"

#include <cydevice_trm.h>
#include <CyLib.h>
#include <GEIGER_INTRPT.h>

static void WriteMotorReg( unsigned int reg, int data ) ;


#define MOTOR1_DEVICE_ADRS0 (B1100100)
#define MOTOR1_DEVICE_ADRS1 (B1100101)
#define MOTOR1_CTRL_ADRS 0
#define MOTOR1_STS_ADRS (MOTOR1_CTRL_ADRS)

#define MOTOR_FREE 0
#define MOTOR_CW 1
#define MOTOR_CCW 2
#define MOTOR_BREAK 3

#define LOWEST_VOLT_INDEX 6
#define HIGHEST_VOLT_INDEX 0x3f //(58 level )

//田宮ギヤボックスの場合、31〜63 で使用
#define TAMIYA_MAX 63
#define TAMIYA_MIN 31
#define COEF 100

static int DeviceAddress = MOTOR1_DEVICE_ADRS0 ;

// speed は、0〜100
void SetTamiyaGearBoxSpeed( int channel, int speed )
{
    SetMotorChannel( channel ) ;
    BOOL minusSign = FALSE ;

    if( speed == 0 ) {
        SetVoltageAndDirection( 0 ) ;
        return ;
    }
    if( channel != 0 ) {
        speed = - speed ;
    }

    speed = ( speed * ( TAMIYA_MAX - TAMIYA_MIN ) ) /  100 ;
    if( speed >= 0 ) {
        speed += TAMIYA_MIN ;
    }
    else {
        speed -= TAMIYA_MIN ;
    }

    xprintf( "channel=%d SetVoltageAndDirection(%d)\n",channel,speed);
    SetVoltageAndDirection( speed ) ;
}

void SetMotorChannel( int channel )
{
    if( channel == 0 ) {
        DeviceAddress = MOTOR1_DEVICE_ADRS0 ;
    }
    else {
        DeviceAddress = MOTOR1_DEVICE_ADRS1 ;
    }
}

void SetVoltageAndDirection( int voltage )
{
    BOOL sign ;

    if( voltage == 0 ) {
        unsigned char data = ( LOWEST_VOLT_INDEX << 2 ) | MOTOR_FREE ;
        WriteMotorReg( MOTOR1_CTRL_ADRS, data ) ;
        return ;
    }

    if( voltage < 0 ) {
        sign = TRUE ;
        voltage = 0 - voltage ;
    }
    else {
        sign = FALSE ;
    }
    if( voltage < LOWEST_VOLT_INDEX ) {
        voltage = LOWEST_VOLT_INDEX ;
    }
    if( voltage > HIGHEST_VOLT_INDEX ) {
        voltage = HIGHEST_VOLT_INDEX ;
    }
    if( sign ) {
        //xprintf( " volt= + %05d ", voltage ) ;
    }
    else {
        //xprintf( " volt= - %05d ", voltage ) ;
    }
    unsigned char regValue = voltage ;
    regValue <<= 2 ;
    if( sign ) {
        regValue |= MOTOR_CCW ;
    }
    else {
        regValue |= MOTOR_CW ;
    }
    xprintf( "regvalue=%08B ", voltage ) ;
    WriteMotorReg( MOTOR1_CTRL_ADRS, regValue ) ;
}
static void WriteMotorReg( unsigned int reg, int data )
{
    WriteRegI2C( DeviceAddress, reg, data ) ;
}

#if 0


//  加速度センサー KXP84-2050
#define ACCL_ADRS_WRITE (0x30u>>1)       //デバイスアドレスのshiftは、自動生成されたI2Cのソースコードの中で行われる
#define ACCL_ADRS_READ (ACCL_ADRS_WRITE) //デバイスアドレスに含まれる R/~W は、自動生成されたI2Cのソースコードの中で行われる

#define FFINT 0x6u //ADDRESS OF FF_INT
#define FFDLY 0x7u //ADDRESS OF FF_DELAY
#define MTINT 0x8u //ADDRESS OF MOT_INT
#define MTDLY 0x9u //ADDRESS OF MOT_DELAY
#define REGC  0xAu //ADDRESS OF REGISTER C
#define REGB  0xBu //ADDRESS OF REGISTER B
#define REGX  0x0u //ADDRESS OF DATAREGISTER X
#define REGY  0x2u //ADDRESS OF DATAREGISTER Y
#define REGZ  0x4u //ADDRESS OF DATAREGISTER Z
#define GRAVITY_OFFSET 2048

volatile BOOL InUseI2C ;

static void WaitRelease( void )
{
    LOOP() {
        if( InUseI2C == FALSE ) {
            InUseI2C = TRUE ;
            break ;
        }
        Sleep(1);
    }
}
void WriteAcclReg( unsigned int reg, int data )
{
    WaitRelease() ;
    WriteRegI2C( ACCL_ADRS_WRITE, reg, data ) ;
    InUseI2C = FALSE ;
}
unsigned int ReadAcclReg( int reg )
{
    unsigned int data ;
    WaitRelease() ;
    data = ReadRegI2C( ACCL_ADRS_READ, reg ) ;
    InUseI2C = FALSE ;
    return data & 0xff ;
}
void InitAccl( void )
{
    uint8 buf ;
    WriteAcclReg( REGB,  B00000110 ) ;
    WriteAcclReg( REGC,  B00000000 ) ;
    WriteAcclReg( FFINT, B00010100 ) ;
    WriteAcclReg( FFDLY, B00010100 ) ;
    WriteAcclReg( MTINT, B01001101 ) ;
    WriteAcclReg( MTDLY, B00010100 ) ;
    Sleep( 10 ) ;
}

int ReadAcclData( int reg )
{
    unsigned int high, low ;
    high = ReadAcclReg( reg ) ;
    low = ReadAcclReg( reg + 1 ) ;
    low >>= 4 ;
    low = ( high << 4 ) | low ;
    return low ;
}
static void ResetAccelMeter( void )
{
    ACCL_RST_PLUS_Write( 0 ) ;
    ACCL_RST_PLUS_Write( 1 ) ;
    Sleep(1);
    ACCL_RST_PLUS_Write( 0 ) ;
}



#endif
